@@ -55,7 +55,7 @@ func Run(ctx context.Context, opt Options) (err error) {
 		Options:       opt,
 		listener:      l,
 		currentChange: latestChangeAt,
-		tunnels:       make(map[string]*wg.Tunnel),
+		tunnels:       make(map[tunnelKey]*wg.Tunnel),
 	}).serve(ctx, l)
 
 	return
@@ -102,6 +102,11 @@ func latestChange(path string) (at time.Time, err error) {
 	return
 }
 
+type tunnelKey struct {
+	orgSlug     string
+	networkName string
+}
+
 type server struct {
 	Options
 
@@ -109,7 +114,7 @@ type server struct {
 
 	mu            sync.Mutex
 	currentChange time.Time
-	tunnels       map[string]*wg.Tunnel
+	tunnels       map[tunnelKey]*wg.Tunnel
 }
 
 type terminateError struct{ error }
@@ -222,18 +227,20 @@ func (s *server) checkForConfigChange() (err error) {
 	return
 }
 
-func (s *server) buildTunnel(ctx context.Context, org *fly.Organization, recycle bool) (tunnel *wg.Tunnel, err error) {
+func (s *server) buildTunnel(ctx context.Context, org *fly.Organization, recycle bool, network string) (tunnel *wg.Tunnel, err error) {
 	s.mu.Lock()
 	defer s.mu.Unlock()
 
+	tk := tunnelKey{orgSlug: org.Slug, networkName: network}
+
 	// not checking the region is intentional, it's static during the lifetime of the agent
-	if tunnel = s.tunnels[org.Slug]; tunnel != nil && !recycle {
+	if tunnel = s.tunnels[tk]; tunnel != nil && !recycle {
 		// tunnel already exists
 		return
 	}
 
 	var state *wg.WireGuardState
-	if state, err = wireguard.StateForOrg(ctx, s.Client, org, os.Getenv("FLY_AGENT_WG_REGION"), "", recycle); err != nil {
+	if state, err = wireguard.StateForOrg(ctx, s.Client, org, os.Getenv("FLY_AGENT_WG_REGION"), "", recycle, network); err != nil {
 		return
 	}
 
@@ -248,7 +255,7 @@ func (s *server) buildTunnel(ctx context.Context, org *fly.Organization, recycle
 		}
 	}
 
-	s.tunnels[org.Slug] = tunnel
+	s.tunnels[tk] = tunnel
 
 	return
 }
@@ -297,15 +304,17 @@ func (s *server) fetchInstances(ctx context.Context, tunnel *wg.Tunnel, app stri
 	return ret, nil
 }
 
-func (s *server) tunnelFor(slug string) *wg.Tunnel {
+func (s *server) tunnelFor(slug, network string) *wg.Tunnel {
 	s.mu.Lock()
 	defer s.mu.Unlock()
 
-	return s.tunnels[slug]
+	tk := tunnelKey{orgSlug: slug, networkName: network}
+
+	return s.tunnels[tk]
 }
 
-func (s *server) probeTunnel(ctx context.Context, slug string) (err error) {
-	tunnel := s.tunnelFor(slug)
+func (s *server) probeTunnel(ctx context.Context, slug, network string) (err error) {
+	tunnel := s.tunnelFor(slug, network)
 	if tunnel == nil {
 		err = agent.ErrTunnelUnavailable
 
@@ -344,10 +353,17 @@ func (s *server) validateTunnelsUnlocked() error {
 	}
 
 	for slug, tunnel := range s.tunnels {
-		if peers[slug] == nil {
+		sk := slug.orgSlug
+		if slug.networkName != "" {
+			sk = fmt.Sprintf("%s-%s", sk, slug.networkName)
+		}
+
+		s.printf("%s, %+v", sk, peers)
+
+		if peers[sk] == nil {
 			delete(s.tunnels, slug)
 
-			s.printf("no peer for %s in config - closing tunnel ...", slug)
+			s.printf("no peer for '%s' in config - closing tunnel ...", slug)
 
 			if err := tunnel.Close(); err != nil {
 				s.printf("failed closing tunnel: %v", err)
