@@ -6,15 +6,14 @@ import (
 
 	"github.com/spf13/cobra"
 
-	"github.com/superfly/flyctl/api"
-	"github.com/superfly/flyctl/flaps"
+	fly "github.com/superfly/fly-go"
+	"github.com/superfly/fly-go/flaps"
 	"github.com/superfly/flyctl/iostreams"
 
-	"github.com/superfly/flyctl/client"
-	"github.com/superfly/flyctl/internal/buildinfo"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flapsutil"
 	"github.com/superfly/flyctl/internal/prompt"
 	"github.com/superfly/flyctl/internal/render"
 )
@@ -54,12 +53,6 @@ may be fetched with 'fly config save -a <app_name>'`
 			Description: "Use the machines platform",
 			Hidden:      true,
 		},
-		flag.Bool{
-			Name:        "nomad",
-			Description: "Use the nomad platform",
-			Default:     false,
-			Hidden:      true,
-		},
 		flag.Org(),
 	)
 
@@ -75,19 +68,9 @@ func RunCreate(ctx context.Context) (err error) {
 		aName         = flag.FirstArg(ctx)
 		fName         = flag.GetString(ctx, "name")
 		fGenerateName = flag.GetBool(ctx, "generate-name")
-		apiClient     = client.FromContext(ctx).API()
+		apiClient     = fly.ClientFromContext(ctx)
 	)
 
-	machines := true
-
-	if flag.GetBool(ctx, "nomad") {
-		if buildinfo.IsDev() {
-			machines = false
-		} else {
-			return fmt.Errorf("creating new apps on the nomad platform is no longer supported")
-		}
-	}
-
 	var name string
 	switch {
 	case aName != "" && fName != "" && aName != fName:
@@ -112,14 +95,14 @@ func RunCreate(ctx context.Context) (err error) {
 		return
 	}
 
-	input := api.CreateAppInput{
+	input := fly.CreateAppInput{
 		Name:           name,
 		OrganizationID: org.ID,
-		Machines:       machines,
+		Machines:       true,
 	}
 
 	if v := flag.GetString(ctx, "network"); v != "" {
-		input.Network = api.StringPointer(v)
+		input.Network = fly.StringPointer(v)
 	}
 
 	app, err := apiClient.CreateApp(ctx, input)
@@ -127,7 +110,10 @@ func RunCreate(ctx context.Context) (err error) {
 		return err
 	}
 
-	if err := flaps.WaitForApp(ctx, app.Name); err != nil {
+	f, err := flapsutil.NewClientWithOptions(ctx, flaps.NewClientOpts{AppName: app.Name})
+	if err != nil {
+		return err
+	} else if err := f.WaitForApp(ctx, app.Name); err != nil {
 		return err
 	}
 
